## Contents

Fault section data is stored in [GeoJSON](https://geojson.org) files, organized in directories by state and fault name. Each fault section file defines a fault trace or traces as a geometry `Feature`. Some sections may also include a fault 'zone' feature that defines an area (polygon) around a fault section over which seismic activity associated with the section may occur. Each fault section directory also contains a README file, with history and reference information on the section or sections. The GeoJSON `id` member is used to store a unique integer identifier for each fault section that is consistent across database and NSHM updates. All other parameters that define a section are stored in the GeoJSON `properties` object.

Two types of sections are currently present in the repository: crustal fault sections and subduction interface sections, each with distinct properties. Crustal fault section geometry is defined by a single trace. Subduction interface geometry is defined by two or more traces that are ordered by increasing depth.

#### Crustal Fault Section Properties

The geologic slip or displacement rate reported with each crustal fault section is the geologic rate used to model earthquake rates in an NSHM.

| Property      | Value              | Required | Notes |
| ------------- | ------------------ | -------- | ----- |
| `name`        | string             | yes      |       |
| `state`       | string             | yes      |       |
| `states`      | [string]           | no       | If present, primary `state` should be listed first |
| `dip`         | number             | yes      | [10..90]° |
| `rake`        | number             | yes      | [-180..180]° (Aki & Richards, 1980) |
| `upper-depth` | number             | yes      | [0..40] km (positive down) |
| `lower-depth` | number             | yes      | [0..40] km (positive down), > `upper-depth` |
| `rate`        | number             | no¹      | (0..60] Slip or displacement rate in mm/yr |
| `rate-type`   | string             | yes      | [`SLIP`, `VERTICAL_SLIP`, `RECURRENCE`]² |

¹ `rate` element will be absent if `rateType` is `RECURRENCE`  
² `SLIP_RATE` = on-plane slip in the direction of rake  
² `VERTICAL_SLIP_RATE` = vertical displacement rate irrespective of fault orientation  
² `RECURRENCE` = marker for faults for which a geologic slip rate is likely unknown  

#### Subduction Interface Section Properties

Subduction interface earthquake rates are constrained by recurrence models and therefore do not include slip or convergence rate data.

| Property      | Value              | Required | Notes |
| ------------- | ------------------ | -------- | ----- |
| `name`        | string             | yes      |       |
| `state`       | string             | yes      |       |
| `states`      | [string]           | no       | If present, primary `state` should be listed first |

#### Criteria for Inclusion

The following rules apply when considering additions or modifications to the database.

* __Publication:__ Section geometry and slip rate data should be published in a peer-reviewed journal, USGS report, U.S. state geological survey report, or expert panel report, for example the Working Group on California Earthquake Probabilities (WGCEP).

* __Recency of activity:__ Historically fault sections included in NSHMs have exhibited activity in the latest Quaternary, <15,000 years. Late Quaternary fault sections may now also be considered when developing interconnected fault systems, for example the UCERF3 fault models.

The following general rules apply when developing additions or modifications to the database.

* __Minimum length:__ Half the regional average seismogenic thickness of the crust, or around 7 km in the Western U.S.

* __Trace discretization:__ >1 km , however, many sections are much coarser. Bear in mind that increased discretization and trace articulation will be reflected in the subsurface representation of a fault section in a hazard model, which may not be justified.

* __Right-hand rule:__ Trace must adhere to the U.S. structural geology right-hand-rule.

* __Rake:__ Defines a section's sense of motion; values should be close to those listed below to imply the sense of motion listed (Aki & Richards, 1980):
  - Right-lateral strike-slip: `-180°` or `180°`
  - Left-lateral strike-slip: `0°`
  - Normal: `-90°`
  - Reverse: `90°`

#### Numbering

Fault section numeric identifiers are grouped by state or territory. Some ID ranges are used to identify the fault components of larger more complex source models and logic trees that span multiple states, for example the Cascadia subduction & New Madrid fault zones. These ID's are used directly in hazard calculation tracking. See model format documentation for details on rupture models and fault section stitching.

| State or Group                       | ID Range      |
| ------------------------------------ | ------------- |
| CA                                   | [1..999]      |
| NV                                   | [1000..1999]  |
| AZ                                   | [2000..2099]  |
| CO                                   | [2100..2199]  |
| ID                                   | [2200..2299]  |
| MT                                   | [2300..2399]  |
| NM                                   | [2400..2499]  |
| OR                                   | [2500..2599]  |
| TX                                   | [2600..2699]  |
| UT                                   | [2700..2799]  |
| WA                                   | [2800..2899]  |
| WY                                   | [2900..2999]  |
| New Madrid (MO, AR, IL, KY, MO, TN)¹ | [3000..3099]  |
| Cascadia (WA, CA, OR)²               | [3100..3399]  |
| Other³, RLME⁴                        | [3400..3999]  |
| AK                                   | [4000..4999]  |
| HI                                   | [5000..5999]  |
| AS                                   | [7000..7099]  |
| GU, MP                               | [7100..7199]  |
| PR, VI                               | [7200..7299]  |
| CEUS gridded models                  | [8000..8099]  |
| WUS gridded models                   | [8100..8199]  |
| WUS subduction intraslab models      | [8200..8299]  |
| WUS fault system rupture models      | [8300..8399]  |

¹ New Madrid primary state is MO and used for all multi-section ruptures  
² Cascadia primary state is WA and used for all multi-section ruptures  
³ Includes Meers (OK)  
⁴ CEUS-SSCn repeating large magnitude earthquake (RLME, or zone sources)  

For reference, the following table details how IDs are allocated for sections and ruptures in some fast slipping fault zones.

| Fault zone                | State | ID Range       | Notes                                  |
| ------------------------- | ----- | -------------- | -------------------------------------- |
| San Andreas               | CA    |  [700..719]    | Sections                               |
| San Andreas               | CA    |  [720..779]    | Southern multi-section ruptures, 2008  |
| San Andreas               | CA    |  [780..799]    | Northern multi-section ruptures, 2008  |
| San Jacinto               | CA    |  [800..809]    | Sections                               |
| San Jacinto               | CA    |  [810..839]    | Multi-section ruptures, 2008           |
| Elsinore                  | CA    |  [840..849]    | Sections                               |
| Elsinore                  | CA    |  [850..879]    | Multi-section ruptures, 2008           |
| Garlock                   | CA    |  [880..889]    | Sections                               |
| Garlock                   | CA    |  [890..899]    | Multi-section ruptures, 2008           |
| Hayward - Rodgers Creek   | CA    |  [900..909]    | Sections                               |
| Hayward - Rodgers Creek   | CA    |  [910..919]    | Multi-section ruptures, 2008           |
| Calaveras                 | CA    |  [920..929]    | Sections                               |
| Calaveras                 | CA    |  [930..939]    | Multi-section ruptures, 2008           |
| Other CA                  | CA    |  [950..964]    | 'connected' ruptures, 2008             |
| Wasatch                   | UT    |  [2780..2799]  | Sections                               |

#### International

The following fault sections cross international borders and are associated with the states listed.

| Faults in or extending into Mexico | State ID |
| ---------------------------------- | -------- |
| Amargosa                           | TX       |
| Caballo                            | TX       |
| Cañada David                       | CA       |
| Cerro Prieto                       | CA       |
| Coronado Bank (alt 1)              | CA       |
| Coronado Bank (alt 2)              | CA       |
| East Fanklin Mountains             | TX       |
| Imperial                           | CA       |
| Laguna Salada                      | CA       |
| San Clemente                       | CA       |
| San Diego Trough                   | CA       |
| West Indio Mountains               | TX       |

| Faults in or extending into Canada | State ID |
| ---------------------------------- | -------- |
| Aleutian Arc                       | AK       |
| Denali (east)                      | AK       |
| Fairweather (onshore)              | AK       |
| Totschunda                         | AK       |
